@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.081;
+our $VERSION = 1.082;
 
 use Prty::Object;
 use Prty::Array;
@@ -1752,28 +1752,28 @@ sub incPaths {
 
 =head2 POD
 
-=head3 extractPod() - Extrahiere POD-Dokumentation aus Perl-Quelltext
+=head3 getPod() - Extrahiere POD-Dokumentation aus Perl-Quelltext
 
 =head4 Synopsis
 
-    $pod = $this->extractPod($file);
-    $pod = $this->extractPod(\$text);
+    $pod = $this->getPod($file);
+    $pod = $this->getPod(\$text);
     
-    ($pod,$encoding) = $this->extractPod($file);
-    ($pod,$encoding) = $this->extractPod(\$text);
+    ($pod,$encoding) = $this->getPod($file);
+    ($pod,$encoding) = $this->getPod(\$text);
 
 =head4 Description
 
-Extrahiere den POD-Code aus Datei $file bzw. Quelltext $text und
-liefere diesen zurück. Ist (per =encoding) ein Encoding definiert,
-dekodiere den gelieferten POD-Code entsprechend. Im Array-Kontext
-liefere zusätzlich zum POD-Code das Encoding.
+Lies den POD-Code aus Datei $file bzw. Quelltext $text und liefere
+diesen zurück. Ist ein Encoding definiert, dekodiere den
+gelieferten POD-Code entsprechend. Im Array-Kontext liefere
+zusätzlich zum POD-Code das Encoding.
 
 =cut
 
 # -----------------------------------------------------------------------------
 
-sub extractPod {
+sub getPod {
     my ($this,$input) = @_;
 
     my $pod = '';
@@ -1807,6 +1807,37 @@ sub extractPod {
 
 # -----------------------------------------------------------------------------
 
+=head3 getPodValues() - Liefere Content von POD-Abschnitten
+
+=head4 Synopsis
+
+    $this->getPodValues($file,@keyRef);
+    $this->getPodValues(\$text,@keyRef);
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub getPodValues {
+    my ($this,$input,%keyRef) = @_;
+
+    my $pod = $this->getPod($input);
+    for my $key (keys %keyRef) {
+        my $ref = $keyRef{$key};
+        if ($$ref) {
+            next;
+        }
+        my ($val) = $pod =~ /(?:^|\n\n)=head1 $key\n\n(.*?)(\n\n=head1|$)/s;
+        if (defined($val) && $val ne '') {
+            $$ref = $val;
+        }
+    }
+    
+    return;
+}
+
+# -----------------------------------------------------------------------------
+
 =head3 removePod() - Entferne POD-Abschnitte aus Quelltext
 
 =head4 Synopsis
@@ -1840,7 +1871,7 @@ sub removePod {
 
 =head1 VERSION
 
-1.081
+1.082
 
 =head1 AUTHOR
 
