@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.081;
+our $VERSION = 1.082;
 
 # -----------------------------------------------------------------------------
 
@@ -20,9 +20,11 @@ L<Prty::Hash>
 
 =head1 DESCRIPTION
 
-Ein Objekt der Klasse repräsentiert einen POD-Generator. Die
-Methoden der Klasse erzeugen die Konstrukte, aus denen ein
-POD-Dokument aufgebaut ist.
+Dokumentation der POD-Syntax: L<http://perldoc.perl.org/perlpod.html>
+
+Ein Objekt der Klasse repräsentiert einen POD-Generator. Mit den
+Methoden der Klasse können beliebige POD-Dokumente erzeugt werden,
+wobei die Syntaxregeln automatisch beachtet werden.
 
 =head1 ATTRIBUTES
 
@@ -75,9 +77,9 @@ sub new {
 
 # -----------------------------------------------------------------------------
 
-=head2 Abschnitt-Kommandos
+=head2 Abschnitts-Kommandos
 
-Anmerkung: Die Methoden ergänzen den generierten POD-Code um eine
+Alle Abschnitts-Methoden ergänzen den generierten POD-Code um eine
 Leerzeile am Ende, so dass das nächste Konstrukt direkt angefügt
 werden kann. Diese Leezeile ist in den Beispielen nicht
 wiedergegeben.
@@ -116,15 +118,33 @@ sub encoding {
 
 =head4 Synopsis
 
+    $pod = $pg->section($level,$title);
     $pod = $pg->section($level,$title,$body);
 
 =head4 Description
 
 Erzeuge einen Abschnitt der Tiefe $level mit dem Titel $title und
 dem Abschnitts-Körper $body und liefere den resultierenden
-POD-Code zurück.
+POD-Code zurück. Ist $body nicht angegeben oder ein Leerstring,
+wird nur der Titel erzeugt.
 
-=head4 Example
+=head4 Examples
+
+=over 2
+
+=item *
+
+ohne Body
+
+    $pg->section(1,'Test');
+
+erzeugt
+
+    =head1 Test
+
+=item *
+
+mit Body
 
     $pg->section(1,'Test',"Dies ist\nein Test.");
 
@@ -135,14 +155,22 @@ erzeugt
     Dies ist
     ein Test.
 
+=back
+
 =cut
 
 # -----------------------------------------------------------------------------
 
 sub section {
     my ($self,$level,$title,$body) = @_;
-    $body =~ s/\s+$//;
-    return "=head$level $title\n\n$body\n\n";
+
+    my $pod = "=head$level $title\n\n";
+    if (defined($body) && $body ne '') {
+        $body =~ s/\s+$//;
+        $pod .= "$body\n\n";
+    }
+
+    return $pod;
 }
 
 # -----------------------------------------------------------------------------
@@ -321,7 +349,7 @@ oder
 
     $pg->definitionList([['A','Eins'],['B','Zwei']]);
 
-erzeugt
+erzeugen
 
     =over 4
     
@@ -364,7 +392,103 @@ sub definitionList {
 
 # -----------------------------------------------------------------------------
 
-=head3 cut() - Beende POD-Abschnitt
+=head3 for() - Formatierer-Code
+
+=head4 Synopsis
+
+    $pod = $pg->for($format,$code);
+
+=head4 Description
+
+Definiere Code $code für Formatierer des Formats $format und
+liefere das Resultat zurück. Ist $code einzeilig, wird eine
+for-Instruktion erzeugt, ansonsten eine begin/end-Instruktion.
+
+=head4 Examples
+
+=over 2
+
+=item *
+
+einzeiliger Code
+
+    $pg->for('html','<img src="figure1.png" />');
+
+erzeugt
+
+    =for html <img src="figure1.png" />
+
+=item *
+
+mehrzeiliger Code
+
+    $pg->for('html',qq|Ein Bild:\n<img src="figure1.png" />|);
+
+erzeugt
+
+    =begin html
+    
+    Ein Bild:
+    <img src="figure1.png" />
+    
+    =end html
+
+=back
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub for {
+    my ($self,$format,$code) = @_;
+
+    $code =~ s/\s+$//;
+
+    my $pod;
+    if ($code =~ tr/\n//) {
+        $pod = "=begin $format\n\n$code\n\n=end $format\n\n";
+    }
+    else {
+        $pod = "=for $format $code\n\n";
+    }
+        
+    return $pod;
+}
+
+# -----------------------------------------------------------------------------
+
+=head3 pod() - Beginne POD-Block
+
+=head4 Synopsis
+
+    $pod = $pg->pod;
+
+=head4 Description
+
+Beginne einen POD-Block. Diese Instruktion ist nur nötig, wenn der
+Block mit einem einfachen Text beginnt, denn I<jede> andere
+POD-Instruktion beginnt ebenfalls einen POD-Block.
+
+=head4 Example
+
+    $pg->pod;
+
+erzeugt
+
+    =pod
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub pod {
+    my $self = shift;
+    return "=pod\n\n";
+}
+
+# -----------------------------------------------------------------------------
+
+=head3 cut() - Beende POD-Block
 
 =head4 Synopsis
 
@@ -372,8 +496,8 @@ sub definitionList {
 
 =head4 Description
 
-Erzeuge die Markierung, die einen POD-Abschnitt beendet, wenn
-danach Perl-Code folgen soll.
+Beende einen POD-Block. Diese Instruktion ist nicht nötig, wenn
+danach kein Perl-Code folgt.
 
 =head4 Example
 
@@ -396,7 +520,7 @@ sub cut {
 
 =head2 Format-Codes
 
-=head3 fmt() - Liefere Formatting Code (a.k.a. "Inline-Segment")
+=head3 fmt() - Format-Code
 
 =head4 Synopsis
 
@@ -418,13 +542,13 @@ Nomal:
     =>
     C<$x>
 
-Eingebettet >:
+1x > eingebettet:
 
     $pg->fmt('C','$class->new()');
     =>
     C<< $class->new() >>
 
-2x Eingebettet >:
+2x > eingebettet:
 
     $pg->fmt('C','$x >> $y');
     =>
@@ -456,7 +580,7 @@ sub fmt {
 
 =head1 VERSION
 
-1.081
+1.082
 
 =head1 AUTHOR
 
